#! /bin/bash
set -ex

nagios_plugin_dir="$1"
ce_state_dir=/var/spool/arc/nagios/ce-state

export PATH="$PATH:$nagios_plugin_dir"
cp -f ci/90-ci.ini /etc/arc/nagios/90-ci.ini

install -m 755 -d "$ce_state_dir"
install -m 755 -d $HOME/.globus
install -m 644 {/mnt,$HOME}/.globus/usercert.pem
install -m 600 {/mnt,$HOME}/.globus/userkey.pem
install -m 755 -d /etc/grid-security/certificates
cp -dR --preserve=mode,timestamps -t /etc/grid-security/certificates/ \
    /mnt/grid-security/certificates/*
export X509_USER_CERT=$HOME/.globus/usercert.pem
export X509_USER_KEY=$HOME/.globus/userkey.pem
arcproxy --version
arcproxy

dump_failed()
{
    find /var/spool/arc/nagios -name \*.xrsl | while read jobdesc; do
	echo "Content of $jobdesc:"
	cat "$jobdesc"
	echo ""
    done
}
trap dump_failed EXIT

# Submit Jobs

for host in $CE_HOSTS; do
    check_arcce_submit --how-invoked=manual -H $host \
	--ce https://$host:443/arex \
	--termination-service ci-termination \
	--test ci-script-1 \
	--test ci-script-2 \
	--test ci-staging \
	-O ci_pwd_var=PWD
done

# Fetch Jobs

set +x
touch monitor.out
while true; do
    ces=
    for ce in `find $ce_state_dir -name active.map`; do
	ce=${ce%/active.map}
	ce=${ce##*/}
	ces="$ces${ces:+ }$ce"
    done
    [ "$ces" != "" ] || break
    echo "Waiting for $ces"
    sleep 5
    rm -f monitor.tmp
    check_arcce_monitor --how-invoked=manual 2>&1 | tee monitor.tmp
    grep -F PROCESS_SERVICE_CHECK_RESULT monitor.tmp \
      | sed 's/.*PROCESS_SERVICE_CHECK_RESULT;//' \
      | tr ';' ' ' \
      | while read host service status_code msg; do
	    mkdir -p "result/$host"
	    echo -n "$status_code" > "result/$host/$service.status"
	done
done
check_arcce_clean --how-invoked=manual

# Inspect Results and Exit

exitcode=0
for host in $CE_HOSTS; do
    for service in ci-termination ci-script-1 ci-script-2; do
	status_file=result/$host/$service.status
	if [ ! -e "$status_file" ]; then
	    echo "Missing $status_file"
	    exitcode=1
	else
	    status_code=`cat $status_file`
	    if [ $status_code -ne 0 ]; then
		echo "Unexpected status $status_code for $service on $host"
		exitcode=1
	    fi
	fi
    done
done
exit $exitcode
